@@ -8,7 +8,7 @@ use Test::More;
 
 use File::Find::Object::Rule 0.0301;
 
-our $VERSION = '0.0102';
+our $VERSION = '0.0103';
 
 sub new
 {
@@ -149,6 +149,12 @@ Or, if you want the test to be optional:
 This module is used to test for lack of trailing space. See the synopsis
 for more details.
 
+B<NOTE:> there is an older CPAN distribution titled L<Test::EOL> that also
+supports testing for trailing space / trailing whitespace, although it
+has some limitations that L<Test::TrailingSpace> does not have, and also
+only calls it "trailing whitespace", rather than "trailing space".
+Whenever possible, one should prefer to use it, instead of this module.
+
 =head1 METHODS
 
 =head2 new({ root => ".", filename_regex => qr/\. ... \z/,})
@@ -169,6 +175,16 @@ trailing space.
 
 Shlomi Fish, L<http://www.shlomifish.org/> .
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * Test::EOL
+
+L<Test::EOL>
+
+=back
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2012 Shlomi Fish.
